@@ -32,6 +32,7 @@ estimate(coef=bb$riskG$riskG01[,1],vcov=crossprod(bb$riskG.iid$riskG01),f=functi
 
 
 ## -----------------------------------------------------------------------------
+
 ## 2 levels for each response , fixed weights 
 datat$response.f <- as.factor(datat$response)
 bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),datat,time=2,cause=c(1),response.code=2,
@@ -59,19 +60,22 @@ datat$A1.23.f <- as.factor(datat$A1.23.f)
 dtable(datat,~A1.23.f+response|Count2==1)
 ###
 bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),datat,time=2,cause=c(1),response.code=2,
-		treat.model0=A0.f~+1, treat.model1=A1.23.f~A0.f*response.f,
-		augmentR0=~X01+X02, augmentR1=~X11+X12,
-		augmentC=~X01+X02+A11t+A12t+X11+X12+TR, cens.model=~strata(A0.f),
-		estpr=c(1,0),pi1=c(0.3,0.5))
+	treat.model0=A0.f~+1,treat.model1=A1.23.f~A0.f*response.f,
+	augmentR0=~X01+X02, augmentR1=~X11+X12,
+	augmentC=~X01+X02+A11t+A12t+X11+X12+TR, cens.model=~strata(A0.f),
+        estpr=c(1,0),pi1=c(0.3,0.5))
 bb
 
+
 ## 2 and 3 levels for each response , estimated 
 bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),datat,time=2,cause=c(1),response.code=2,
-		treat.model0=A0.f~+1, treat.model1=A1.23.f~A0.f*response.f,
-		augmentR0=~X01+X02, augmentR1=~X11+X12,
-		augmentC=~X01+X02+A11t+A12t+X11+X12+TR, cens.model=~strata(A0.f),estpr=c(1,1))
+	treat.model0=A0.f~+1, treat.model1=A1.23.f~A0.f*response.f,
+	augmentR0=~X01+X02, augmentR1=~X11+X12,
+	augmentC=~X01+X02+A11t+A12t+X11+X12+TR,cens.model=~strata(A0.f),
+	estpr=c(1,1))
 bb
 
+
 ## 2 and 1 level for each response 
 datat$A1.21.f <- as.numeric(datat$A1.f)
 dtable(datat,~A1.21.f+response|Count2==1)
@@ -80,16 +84,18 @@ dtable(datat,~A1.21.f+response|Count2==1)
 datat$A1.21.f <- as.factor(datat$A1.21.f)
 dtable(datat,~A1.21.f+response|Count2==1)
 bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),datat,time=2,cause=c(1),response.code=2,
-		treat.model0=A0.f~+1, treat.model1=A1.21.f~A0.f*response.f,
-		augmentR0=~X01+X02, augmentR1=~X11+X12,
-		augmentC=~X01+X02+A11t+A12t+X11+X12+TR, cens.model=~strata(A0.f),estpr=c(1,1))
+	treat.model0=A0.f~+1, treat.model1=A1.21.f~A0.f*response.f,
+	augmentR0=~X01+X02, augmentR1=~X11+X12,
+	augmentC=~X01+X02+A11t+A12t+X11+X12+TR,cens.model=~strata(A0.f),
+	estpr=c(1,1))
 bb
 
 ## known weights 
 bb <- binregTSR(Event(entry,time,status)~+1+cluster(id),datat,time=2,cause=c(1),response.code=2,
-		treat.model0=A0.f~+1, treat.model1=A1.21.f~A0.f*response.f,
-		augmentR0=~X01+X02, augmentR1=~X11+X12,
-		augmentC=~X01+X02+A11t+A12t+X11+X12+TR, cens.model=~strata(A0.f),estpr=c(1,0),pi1=c(0.5,1))
+	treat.model0=A0.f~+1, treat.model1=A1.21.f~A0.f*response.f,
+	augmentR0=~X01+X02, augmentR1=~X11+X12,
+	augmentC=~X01+X02+A11t+A12t+X11+X12+TR,
+	cens.model=~strata(A0.f),estpr=c(1,0),pi1=c(0.5,1))
 bb
 
 ## -----------------------------------------------------------------------------
@@ -98,14 +104,21 @@ calgt <- calgb8923
 
 tm=At.f~factor(Count2)+age+sex+wbc
 tm=At.f~factor(Count2)
+tm=At.f~factor(Count2)*A0.f
+
+head(calgt)
 ll0 <- phreg_IPTW(Event(start,time,status==1)~strata(A0,A10)+cluster(id),calgt,treat.model=tm)
 pll0 <- predict(ll0,expand.grid(A0=0:1,A10=0,id=1))
 ll1 <- phreg_IPTW(Event(start,time,status==1)~strata(A0,A11)+cluster(id),calgt,treat.model=tm)
 pll1 <- predict(ll1,expand.grid(A0=0:1,A11=1,id=1))
-plot(pll0,se=1,lwd=2,col=1:2,lty=1,xlab="time (months)")
-plot(pll1,add=TRUE,col=3:4,se=1,lwd=2,lty=1)
+plot(pll0,se=1,lwd=2,col=1:2,lty=1,xlab="time (months)",xlim=c(0,30))
+plot(pll1,add=TRUE,col=3:4,se=1,lwd=2,lty=1,xlim=c(0,30))
+abline(h=0.25)
 legend("topright",c("A1B1","A2B1","A1B2","A2B2"),col=c(1,2,3,4),lty=1)
 
+summary(pll1,times=12)
+summary(pll0,times=12)
+
 ## -----------------------------------------------------------------------------
 sessionInfo()
 
