@@ -24,7 +24,8 @@ nd <- data.frame(platelet=0,age=seq(-2,2,by=0.1))
 pnd <- predictGLM(glm1,nd)
 head(pnd$pred)
 plot(age,pnd$pred[,1],type="l",ylab="predictions",xlab="age",ylim=c(0,0.3))
-matlines(age,pnd$pred[,-1],col=2)
+plotConfRegion(age,pnd$pred[,2:3],col=2)
+###matlines(age,pnd$pred[,-1],col=2,lty=1)
 
 ## -----------------------------------------------------------------------------
 sessionInfo()
